========
Examples
========

`✨ Try kingdon in your browser ✨ <https://tbuli.github.io/teahouse/>`_

2DPGA
-----

.. toctree::
    :maxdepth: 1

    ex_symbolic.ipynb
    ex_pointcloud.ipynb
    ex_2dpga_points_and_lines.ipynb
    ex_2dpga_project_and_reject.ipynb
    ex_2dpga_distances_and_angles.ipynb
    ex_2dpga_inverse_kinematics.ipynb
    ex_2dpga_fivebar.ipynb

3DPGA
-----

.. toctree::
    :maxdepth: 1

    ex_3dpga_points_and_lines.ipynb
    ex_3dpga_distances_and_angles.ipynb

3DCGA
-----

.. toctree::
    :maxdepth: 1

    ex_3dcga_intersections.ipynb
    ex_high_performance.ipynb

